==> melosys-internt-kodeverk-5.11.6-sources.jar: no/nav/melosys/domain/kodeverk/begrunnelser/Art16_1_anmodning_engelsk.java <==
package no.nav.melosys.domain.kodeverk.begrunnelser;

import no.nav.melosys.domain.kodeverk.Kodeverk;

public enum Art16_1_anmodning_engelsk implements Kodeverk {

    UTSENDELSE_MELLOM_24_MN_OG_5_AAR("Ongoing contract for a period longer than 2 and shorter than 5 years."),
	LOENNET_UTL_ENHET_I_KONSERN("The person has a temporary employment contract within the same concern/conglomerate, and will return to the Norwegian employer."),
	ERSTATTER_EN_ANNEN_UNDER_5_AAR("The person is being posted to replace another posted worker, and the aggregated posting period is shorter than 5 years."),
	KORT_OPPDRAG_RETUR_NORSK_AG("The person has not been attached to the Norwegian social insurance system before posting, but will return to the Norwegian employer after a brief posting."),
	IDEELL_ORGANISASJON_IKKE_VESENTLIG_VIRK("Working for a non-profit organisation, but the Norwegian organisation does not normally carry out its activity in Norway."),
	KORTVARIG_NAERINGSDRIVENDE_IKKE_YRKESAKTIV("Short-term assignment as self employed in your country. Has not been performing any activity in Norway immediately prior to the assignment."),
	KORTVARIG_NAERINGSDRIVENDE_ARBEIDSTAKER("Short-term assignment as self employed in your country. Has not been performing self employed activity in Norway prior to the assignment."),
	SAERLIG_GRUNN("Fritekstfelt");

    private final String beskrivelse;

    Art16_1_anmodning_engelsk(String beskrivelse) {
        this.beskrivelse = beskrivelse;
    }

    @Override
    public String getKode() {
        return name();
    }

    @Override
    public String getBeskrivelse() {
        return beskrivelse;
    }
}

==> melosys-internt-kodeverk-5.15.29-sources.jar: no/nav/melosys/domain/kodeverk/begrunnelser/Art16_1_anmodning_engelsk.java <==
package no.nav.melosys.domain.kodeverk.begrunnelser;

import no.nav.melosys.domain.kodeverk.Kodeverk;

public enum Art16_1_anmodning_engelsk implements Kodeverk {

    UTSENDELSE_MELLOM_24_MN_OG_5_AAR("Ongoing contract for a period longer than 2 and shorter than 5 years."),
	LOENNET_UTL_ENHET_I_KONSERN("The person’s salary will partially or entirely be paid by a company within the same concern/conglomerate as the Norwegain employer."),
	ERSTATTER_EN_ANNEN_UNDER_5_AAR("The person is being posted to replace another posted worker, and the aggregated posting period is shorter than 5 years."),
	KORT_OPPDRAG_RETUR_NORSK_AG("The person has not been covered by the Norwegian social security scheme for a sufficient period of time prior to the posting, but will return to the Norwegian employer after a brief posting."),
	IDEELL_ORGANISASJON_IKKE_VESENTLIG_VIRK("Working for a non-profit organization."),
	KORTVARIG_NAERINGSDRIVENDE_IKKE_YRKESAKTIV("Short-term assignment as self employed in your country. Has not been performing any activity in Norway immediately prior to the assignment."),
	KORTVARIG_NAERINGSDRIVENDE_ARBEIDSTAKER("Short-term assignment as self employed in your country. Has not been performing self employed activity in Norway prior to the assignment."),
	SAERLIG_GRUNN("Fritekstfelt");

    private final String beskrivelse;

    Art16_1_anmodning_engelsk(String beskrivelse) {
        this.beskrivelse = beskrivelse;
    }

    @Override
    public String getKode() {
        return name();
    }

    @Override
    public String getBeskrivelse() {
        return beskrivelse;
    }
}
